@@ -1,6 +1,6 @@
 from extras.plugins import PluginConfig
 
-__version__ = "0.4.0"
+__version__ = "0.6.0"
 
 
 class DNSConfig(PluginConfig):
@@ -13,7 +13,14 @@ class DNSConfig(PluginConfig):
     author = "Aurora Research Lab"
     author_email = "info@aurorabilisim.com"
     required_settings = []
-    default_settings = {"loud": False}
+    default_settings = {
+        "zone_default_ttl": 86400,
+        "zone_soa_serial": 1,
+        "zone_soa_refresh": 172800,
+        "zone_soa_retry": 7200,
+        "zone_soa_expire": 2592000,
+        "zone_soa_minimum": 3600,
+    }
 
 
 config = DNSConfig
