@@ -1,5 +1,6 @@
 import django_filters
 from django.db.models import Q
+
 from extras.filters import TagFilter
 from netbox.filtersets import PrimaryModelFilterSet
 from .models import NameServer, Record, Zone
@@ -74,10 +75,11 @@ class RecordFilter(PrimaryModelFilterSet):
         lookup_expr="icontains",
     )
     tag = TagFilter()
+    managed = django_filters.BooleanFilter()
 
     class Meta:
         model = Record
-        fields = ("type", "name", "value", "tag")
+        fields = ("type", "name", "value", "tag", "managed")
 
     def search(self, queryset, name, value):
         """Perform the filtered search."""
