@@ -1,7 +1,7 @@
 from django.urls import path
+
 from extras.views import ObjectChangeLogView
 from netbox_dns.models import Zone, Record, NameServer
-
 from .views import (
     # zone
     ZoneListView,
@@ -11,6 +11,8 @@ from .views import (
     ZoneBulkImportView,
     ZoneBulkEditView,
     ZoneBulkDeleteView,
+    ZoneRecordListView,
+    ZoneManagedRecordListView,
     # nameserver
     NameServerListView,
     NameServerView,
@@ -26,6 +28,8 @@ from .views import (
     RecordBulkImportView,
     RecordBulkEditView,
     RecordBulkDeleteView,
+    # managed record
+    ManagedRecordListView,
 )
 
 app_name = "netbox_dns"
@@ -48,6 +52,14 @@ urlpatterns = [
         name="zone_changelog",
         kwargs={"model": Zone},
     ),
+    path(
+        "zones/<int:pk>/records/", ZoneRecordListView.as_view(), name="zone_record_list"
+    ),
+    path(
+        "zones/<int:pk>/managedrecords/",
+        ZoneManagedRecordListView.as_view(),
+        name="zone_managed_record_list",
+    ),
     #
     # NameServer urls
     #
@@ -97,4 +109,7 @@ urlpatterns = [
         name="record_changelog",
         kwargs={"model": Record},
     ),
+    path(
+        "managedrecords/", ManagedRecordListView.as_view(), name="managed_record_list"
+    ),
 ]
